@@ -32,21 +32,22 @@
 #include <kcalcore/freebusy.h>
 #include <kcalcore/memorycalendar.h>
 
-#include <KDateTime>
 #include <KLocalizedString>
-#include <KLocale>
 
 #include <QDebug>
 #include <QIcon>
 #include <QLocale>
 #include <QProcess>
+#include <QStandardPaths>
 #include <QTest>
+#include <QTimeZone>
 
 QTEST_MAIN(IncidenceFormatterTest)
 #ifndef Q_OS_WIN
 void initLocale()
 {
     setenv("LC_ALL", "en_US.utf-8", 1);
+    setenv("TZ", "UTC", 1);
 }
 Q_CONSTRUCTOR_FUNCTION(initLocale)
 #endif
@@ -69,8 +70,7 @@ void IncidenceFormatterTest::testRecurrenceString()
 
     QDate day(2010, 10, 3);
     QTime tim(12, 0, 0);
-    QDateTime dateTime(day, tim);
-    KDateTime kdt(day, tim, KDateTime::UTC);
+    QDateTime kdt(day, tim, Qt::UTC);
     e1->setDtStart(kdt);
     e1->setDtEnd(kdt.addSecs(60 * 60));      // 1hr event
 
@@ -80,7 +80,7 @@ void IncidenceFormatterTest::testRecurrenceString()
 
     r1->setDaily(1);
     r1->setEndDateTime(kdt.addDays(5));     // ends 5 days from now
-    QString endDateStr = KLocale::global()->formatDateTime(kdt.addDays(5));
+    QString endDateStr = QLocale().toString(kdt.addDays(5).toLocalTime(), QLocale::ShortFormat);
     QCOMPARE(IncidenceFormatter::recurrenceString(e1),
              i18n("Recurs daily until %1", endDateStr));
 
@@ -133,7 +133,7 @@ void IncidenceFormatterTest::testRecurrenceString()
 
     r3->setHourly(1);
     r3->setEndDateTime(kdt.addSecs(5 * 60 * 60));     // ends 5 hrs from now
-    endDateStr = KLocale::global()->formatDateTime(r3->endDateTime());
+    endDateStr = QLocale().toString(r3->endDateTime().toLocalTime(), QLocale::ShortFormat);
     QCOMPARE(IncidenceFormatter::recurrenceString(e3),
              i18n("Recurs hourly until %1", endDateStr));
 
@@ -157,7 +157,7 @@ void IncidenceFormatterTest::testRecurrenceString()
 
 KCalCore::Calendar::Ptr IncidenceFormatterTest::loadCalendar(const QString &name)
 {
-    auto calendar = KCalCore::MemoryCalendar::Ptr::create(KDateTime::UTC);
+    auto calendar = KCalCore::MemoryCalendar::Ptr::create(QTimeZone::utc());
     KCalCore::ICalFormat format;
 
     if (!format.load(calendar, QStringLiteral(TEST_DATA_DIR "/%1.ical").arg(name))) {
@@ -415,7 +415,7 @@ void IncidenceFormatterTest::testFormatIcalInvitation()
 {
     QFETCH(QString, name);
 
-    KCalCore::MemoryCalendar::Ptr calendar(new KCalCore::MemoryCalendar(KDateTime::Spec(KDateTime::UTC)));
+    KCalCore::MemoryCalendar::Ptr calendar(new KCalCore::MemoryCalendar(QTimeZone::utc()));
     InvitationFormatterHelper helper;
 
     QFile eventFile(QStringLiteral(TEST_DATA_DIR "/%1.ical").arg(name));
