@@ -50,6 +50,7 @@
 #include <QDate>
 #include <QWidget>
 #include <QDropEvent>
+#include <QTimeZone>
 
 using namespace KCalCore;
 using namespace KCalUtils;
@@ -67,7 +68,7 @@ public:
     {
     }
 
-    Incidence::Ptr pasteIncidence(const Incidence::Ptr &incidence, KDateTime newDateTime, QFlags<DndFactory::PasteFlag> pasteOptions)
+    Incidence::Ptr pasteIncidence(const Incidence::Ptr &incidence, QDateTime newDateTime, DndFactory::PasteFlags pasteOptions)
     {
         Incidence::Ptr inc(incidence);
 
@@ -90,11 +91,12 @@ public:
                 const int durationInSeconds = event->dtStart().secsTo(event->dtEnd());
                 const int durationInDays = event->dtStart().daysTo(event->dtEnd());
 
-                event->setDtStart(newDateTime);
 
-                if (newDateTime.isDateOnly()) {
+                if (incidence->allDay()) {
+                    event->setDtStart(QDateTime(newDateTime.date(), {}));
                     event->setDtEnd(newDateTime.addDays(durationInDays));
                 } else {
+                    event->setDtStart(newDateTime);
                     event->setDtEnd(newDateTime.addSecs(durationInSeconds));
                 }
             } else if (inc->type() == Incidence::TypeTodo) {
@@ -146,7 +148,6 @@ QMimeData *DndFactory::createMimeData()
     QMimeData *mimeData = new QMimeData;
 
     ICalDrag::populateMimeData(mimeData, d->mCalendar);
-    VCalDrag::populateMimeData(mimeData, d->mCalendar);
 
     return mimeData;
 }
@@ -161,16 +162,15 @@ QDrag *DndFactory::createDrag(QWidget *owner)
 
 QMimeData *DndFactory::createMimeData(const Incidence::Ptr &incidence)
 {
-    MemoryCalendar::Ptr cal(new MemoryCalendar(d->mCalendar->timeSpec()));
+    MemoryCalendar::Ptr cal(new MemoryCalendar(d->mCalendar->timeZone()));
     Incidence::Ptr i(incidence->clone());
     //strip recurrence id's, We don't want to drag the exception but the occurrence.
-    i->setRecurrenceId(KDateTime());
+    i->setRecurrenceId({});
     cal->addIncidence(i);
 
     QMimeData *mimeData = new QMimeData;
 
     ICalDrag::populateMimeData(mimeData, cal);
-    VCalDrag::populateMimeData(mimeData, cal);
 
     QUrl uri = i->uri();
     if (uri.isValid()) {
@@ -193,14 +193,9 @@ QDrag *DndFactory::createDrag(const Incidence::Ptr &incidence, QWidget *owner)
 }
 
 MemoryCalendar::Ptr DndFactory::createDropCalendar(const QMimeData *mimeData)
-{
-    return createDropCalendar(mimeData, d->mCalendar->timeSpec());
-}
-
-MemoryCalendar::Ptr DndFactory::createDropCalendar(const QMimeData *mimeData, const KDateTime::Spec &timeSpec)
 {
     if (mimeData) {
-        MemoryCalendar::Ptr calendar(new MemoryCalendar(timeSpec));
+        MemoryCalendar::Ptr calendar(new MemoryCalendar(QTimeZone::systemTimeZone()));
 
         if (ICalDrag::fromMimeData(mimeData, calendar)
             || VCalDrag::fromMimeData(mimeData, calendar)) {
@@ -299,7 +294,7 @@ bool DndFactory::copyIncidences(const Incidence::List &incidences)
 {
     QClipboard *clipboard = QApplication::clipboard();
     Q_ASSERT(clipboard);
-    MemoryCalendar::Ptr calendar(new MemoryCalendar(d->mCalendar->timeSpec()));
+    MemoryCalendar::Ptr calendar(new MemoryCalendar(d->mCalendar->timeZone()));
 
     Incidence::List::ConstIterator it;
     const Incidence::List::ConstIterator end(incidences.constEnd());
@@ -312,7 +307,6 @@ bool DndFactory::copyIncidences(const Incidence::List &incidences)
     QMimeData *mimeData = new QMimeData;
 
     ICalDrag::populateMimeData(mimeData, calendar);
-    VCalDrag::populateMimeData(mimeData, calendar);
 
     if (calendar->incidences().isEmpty()) {
         return false;
@@ -329,7 +323,7 @@ bool DndFactory::copyIncidence(const Incidence::Ptr &selectedInc)
     return copyIncidences(list);
 }
 
-Incidence::List DndFactory::pasteIncidences(const KDateTime &newDateTime, QFlags<KCalUtils::DndFactory::PasteFlag> pasteOptions)
+Incidence::List DndFactory::pasteIncidences(const QDateTime &newDateTime, PasteFlags pasteOptions)
 {
     QClipboard *clipboard = QApplication::clipboard();
     Q_ASSERT(clipboard);
@@ -373,7 +367,7 @@ Incidence::List DndFactory::pasteIncidences(const KDateTime &newDateTime, QFlags
     return list;
 }
 
-Incidence::Ptr DndFactory::pasteIncidence(const KDateTime &newDateTime, QFlags<KCalUtils::DndFactory::PasteFlag> pasteOptions)
+Incidence::Ptr DndFactory::pasteIncidence(const QDateTime &newDateTime, PasteFlags pasteOptions)
 {
     QClipboard *clipboard = QApplication::clipboard();
     MemoryCalendar::Ptr calendar(createDropCalendar(clipboard->mimeData()));
