@@ -40,9 +40,7 @@
 #include <QDate>
 class InvitationFormatterHelperPrivate;
 
-namespace KCalUtils
-{
-
+namespace KCalUtils {
 class KCALUTILS_EXPORT InvitationFormatterHelper
 {
 public:
@@ -68,66 +66,50 @@ private:
   for tool tips, or a representation for a viewer widget.
 
 */
-namespace IncidenceFormatter
-{
-
+namespace IncidenceFormatter {
 /**
   Create a QString representation of an Incidence in a nice format
   suitable for using in a tooltip.
+  All dates and times are converted to local time for display.
   @param sourceName where the incidence is from (e.g. resource name)
   @param incidence is a pointer to the Incidence to be formatted.
   @param date is the QDate for which the toolTip should be computed; used
   mainly for recurring incidences. Note: For to-dos, this is the due date of
   the occurrence, not the start date.
   @param richText if yes, the QString will be created as RichText.
-  @param spec is an optional time specification which, when specified,
-  will shift the Incidence times to different timezones.
 */
-KCALUTILS_EXPORT QString toolTipStr(const QString &sourceName,
-                                    const KCalCore::IncidenceBase::Ptr &incidence,
-                                    QDate date = QDate(),
-                                    bool richText = true,
-                                    const KDateTime::Spec &spec = KDateTime::Spec());
+KCALUTILS_EXPORT QString toolTipStr(const QString &sourceName, const KCalCore::IncidenceBase::Ptr &incidence, QDate date = QDate(), bool richText = true);
 
 /**
   Create a RichText QString representation of an Incidence in a nice format
   suitable for using in a viewer widget.
+  All dates and times are converted to local time for display.
   @param calendar is a pointer to the Calendar that owns the specified Incidence.
   @param incidence is a pointer to the Incidence to be formatted.
   @param date is the QDate for which the string representation should be computed;
   used mainly for recurring incidences.
-  @param spec is an optional time specification which, when specified,
-  will shift the Incidence times to different timezones.
 */
-KCALUTILS_EXPORT QString extensiveDisplayStr(const KCalCore::Calendar::Ptr &calendar,
-        const KCalCore::IncidenceBase::Ptr &incidence,
-        QDate date = QDate(),
-        const KDateTime::Spec &spec = KDateTime::Spec());
+KCALUTILS_EXPORT QString extensiveDisplayStr(const KCalCore::Calendar::Ptr &calendar, const KCalCore::IncidenceBase::Ptr &incidence,
+                                             QDate date = QDate());
 
 /**
   Create a RichText QString representation of an Incidence in a nice format
   suitable for using in a viewer widget.
+  All dates and times are converted to local time for display.
   @param sourceName where the incidence is from (e.g. resource name)
   @param incidence is a pointer to the Incidence to be formatted.
   @param date is the QDate for which the string representation should be computed;
   used mainly for recurring incidences.
-  @param spec is an optional time specification which, when specified,
-  will shift the Incidence times to different timezones.
 */
-KCALUTILS_EXPORT QString extensiveDisplayStr(const QString &sourceName,
-        const KCalCore::IncidenceBase::Ptr &incidence,
-        QDate date = QDate(),
-        const KDateTime::Spec &spec = KDateTime::Spec());
+KCALUTILS_EXPORT QString extensiveDisplayStr(const QString &sourceName, const KCalCore::IncidenceBase::Ptr &incidence, QDate date = QDate());
 
 /**
   Create a QString representation of an Incidence in format suitable for
   including inside a mail message.
+  All dates and times are converted to local time for display.
   @param incidence is a pointer to the Incidence to be formatted.
-  @param spec is an optional time specification which, when specified,
-  will shift the Incidence times to different timezones.
 */
-KCALUTILS_EXPORT QString mailBodyStr(const KCalCore::IncidenceBase::Ptr &incidence,
-                                     const KDateTime::Spec &spec = KDateTime::Spec());
+KCALUTILS_EXPORT QString mailBodyStr(const KCalCore::IncidenceBase::Ptr &incidence);
 
 /**
   Deliver an HTML formatted string displaying an invitation.
@@ -137,14 +119,11 @@ KCALUTILS_EXPORT QString mailBodyStr(const KCalCore::IncidenceBase::Ptr &inciden
   which will be intrepreted as an invitation.
   @param calendar is a pointer to the Calendar that owns the invitation.
   @param helper is a pointer to an InvitationFormatterHelper.
-  @param outlookCompareStyle if true, display updated invitation comparisons in the style
-  of Microsoft Outlook (tm); else use our own "classic" style.
+
+  @since 5.23.0
 */
 KCALUTILS_EXPORT QString formatICalInvitation(
-    const QString &invitation,
-    const KCalCore::MemoryCalendar::Ptr &calendar,
-    InvitationFormatterHelper *helper,
-    bool outlookCompareStyle);
+    const QString &invitation, const KCalCore::MemoryCalendar::Ptr &calendar, InvitationFormatterHelper *helper);
 
 /**
   Deliver an HTML formatted string displaying an invitation.
@@ -157,15 +136,11 @@ KCALUTILS_EXPORT QString formatICalInvitation(
   @param calendar is a pointer to the Calendar that owns the invitation.
   @param helper is a pointer to an InvitationFormatterHelper.
   @param sender is a QString containing the email address of the person sending the invitation.
-  @param outlookCompareStyle if true, display updated invitation comparisons in the style
-  of Microsoft Outlook (tm); else use our own "classic" style.
+
+  @since 5.23.0
 */
 KCALUTILS_EXPORT QString formatICalInvitationNoHtml(
-    const QString &invitation,
-    const KCalCore::MemoryCalendar::Ptr &calendar,
-    InvitationFormatterHelper *helper,
-    const QString &sender,
-    bool outlookCompareStyle);
+    const QString &invitation, const KCalCore::MemoryCalendar::Ptr &calendar, InvitationFormatterHelper *helper, const QString &sender);
 
 /**
   Build a pretty QString representation of an Incidence's recurrence info.
@@ -182,49 +157,43 @@ KCALUTILS_EXPORT QString recurrenceString(const KCalCore::Incidence::Ptr &incide
   @param shortfmt if false, a short version of each reminder is printed;
   else a longer version of each reminder is printed.
 */
-KCALUTILS_EXPORT QStringList reminderStringList(const KCalCore::Incidence::Ptr &incidence,
-        bool shortfmt = true);
+KCALUTILS_EXPORT QStringList reminderStringList(const KCalCore::Incidence::Ptr &incidence, bool shortfmt = true);
 
 /**
-  Build a QString time representation of a KDateTime object.
-  @param date The date to be formatted.
+  Build a QString time representation of a QTime object.
+  @param time The time to be formatted.
   @param shortfmt If true, display info in short format.
-  @param spec Time spec to use.
   @see dateToString(), dateTimeToString().
 */
-KCALUTILS_EXPORT QString timeToString(const KDateTime &date, bool shortfmt = true,
-                                      const KDateTime::Spec &spec = KDateTime::Spec());
+KCALUTILS_EXPORT QString timeToString(const QTime &time, bool shortfmt = true);
 
 /**
-  Build a QString date representation of a KDateTime object.
+  Build a QString date representation of a QDate object.
+  All dates and times are converted to local time for display.
   @param date The date to be formatted.
   @param shortfmt If true, display info in short format.
-  @param spec Time spec to use.
   @see dateToString(), dateTimeToString().
 */
-KCALUTILS_EXPORT QString dateToString(const KDateTime &date, bool shortfmt = true,
-                                      const KDateTime::Spec &spec = KDateTime::Spec());
+KCALUTILS_EXPORT QString dateToString(const QDate &date, bool shortfmt = true);
+
+KCALUTILS_EXPORT QString formatStartEnd(const QDateTime &start, const QDateTime &end, bool isAllDay);
 
 /**
-  Build a QString date/time representation of a KDateTime object.
+  Build a QString date/time representation of a QDateTime object.
+  All dates and times are converted to local time for display.
   @param date The date to be formatted.
   @param dateOnly If true, don't print the time fields; print the date fields only.
   @param shortfmt If true, display info in short format.
-  @param spec Time spec to use.
   @see dateToString(), timeToString().
 */
-KCALUTILS_EXPORT QString dateTimeToString(const KDateTime &date,
-        bool dateOnly = false,
-        bool shortfmt = true,
-        const KDateTime::Spec &spec = KDateTime::Spec());
+KCALUTILS_EXPORT QString dateTimeToString(const QDateTime &date, bool dateOnly = false, bool shortfmt = true);
 
 /**
   Returns a Calendar Resource label name for the specified Incidence.
   @param calendar is a pointer to the Calendar.
   @param incidence is a pointer to the Incidence.
 */
-KCALUTILS_EXPORT QString resourceString(const KCalCore::Calendar::Ptr &calendar,
-                                        const KCalCore::Incidence::Ptr &incidence);
+KCALUTILS_EXPORT QString resourceString(const KCalCore::Calendar::Ptr &calendar, const KCalCore::Incidence::Ptr &incidence);
 
 /**
   Returns a duration string computed for the specified Incidence.
@@ -245,14 +214,12 @@ KCALUTILS_EXPORT QString incidenceStatusName(KCalCore::Incidence::Status status)
 KCALUTILS_EXPORT QString incidenceStatusStr(const KCalCore::Incidence::Ptr &incidence);
 
 class EventViewerVisitor;
-class ScheduleMessageVisitor;
+template<typename T> class ScheduleMessageVisitor;
 class InvitationHeaderVisitor;
 class InvitationBodyVisitor;
-class IncidenceCompareVisitor;
 class ToolTipVisitor;
 class MailBodyVisitor;
 }
-
 }
 
 #endif
