@@ -26,10 +26,8 @@
 
 #include "ui_recurrenceactionsscopewidget.h"
 
-#include <KLocale>
 #include <KLocalizedString>
 #include <KMessageBox>
-#include <KConfigGroup>
 #include <KGuiItem>
 
 #include <QPointer>
@@ -46,8 +44,9 @@ class ScopeWidget : public QWidget
 {
     Q_OBJECT
 public:
-    ScopeWidget(int availableChoices, const KDateTime &dateTime, QWidget *parent)
-        : QWidget(parent), mAvailableChoices(availableChoices)
+    ScopeWidget(int availableChoices, const QDateTime &dateTime, QWidget *parent)
+        : QWidget(parent)
+        , mAvailableChoices(availableChoices)
     {
         mUi.setupUi(this);
 
@@ -56,7 +55,7 @@ public:
         } else {
             mUi.checkBoxPast->setText(i18nc("@option:check calendar items before a certain date",
                                             "Items before %1",
-                                            KLocale::global()->formatDateTime(dateTime)));
+                                            QLocale().toString(dateTime, QLocale::ShortFormat)));
         }
         if ((mAvailableChoices & SelectedOccurrence) == 0) {
             mUi.checkBoxSelected->hide();
@@ -69,7 +68,7 @@ public:
         } else {
             mUi.checkBoxFuture->setText(i18nc("@option:check calendar items after a certain date",
                                               "Items after %1",
-                                              KLocale::global()->formatDateTime(dateTime)));
+                                              QLocale().toString(dateTime, QLocale::ShortFormat)));
         }
     }
 
@@ -86,7 +85,9 @@ private:
     Ui_RecurrenceActionsScopeWidget mUi;
 };
 
-ScopeWidget::~ScopeWidget() {}
+ScopeWidget::~ScopeWidget()
+{
+}
 
 void ScopeWidget::setMessage(const QString &message)
 {
@@ -128,13 +129,11 @@ int ScopeWidget::checkedChoices() const
     return result;
 }
 
-int RecurrenceActions::availableOccurrences(const Incidence::Ptr &incidence,
-        const KDateTime &selectedOccurrence)
+int RecurrenceActions::availableOccurrences(const Incidence::Ptr &incidence, const QDateTime &selectedOccurrence)
 {
     int result = NoOccurrence;
 
-    if (incidence->recurrence()->recursOn(selectedOccurrence.date(),
-                                          selectedOccurrence.timeSpec())) {
+    if (incidence->recurrence()->recursOn(selectedOccurrence.date(), selectedOccurrence.timeZone())) {
         result |= SelectedOccurrence;
     }
 
@@ -149,16 +148,14 @@ int RecurrenceActions::availableOccurrences(const Incidence::Ptr &incidence,
     return result;
 }
 
-static QDialog *createDialog(QDialogButtonBox::StandardButtons buttons,
-                             const QString &caption, QWidget *mainWidget,
-                             QDialogButtonBox **buttonBox, QWidget *parent)
+static QDialog *createDialog(QDialogButtonBox::StandardButtons buttons, const QString &caption, QWidget *mainWidget, QDialogButtonBox **buttonBox, QWidget *parent)
 {
     QPointer<QDialog> dialog = new QDialog(parent);
     dialog->setWindowTitle(caption);
     QVBoxLayout *mainLayout = new QVBoxLayout();
     dialog->setLayout(mainLayout);
 
-    *buttonBox = new QDialogButtonBox(buttons);
+    *buttonBox = new QDialogButtonBox(buttons, parent);
     QPushButton *okButton = (*buttonBox)->button(QDialogButtonBox::Ok);
     okButton->setDefault(true);
     okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
@@ -175,14 +172,12 @@ static QDialog *createDialog(QDialogButtonBox::StandardButtons buttons,
     return dialog;
 }
 
-int RecurrenceActions::questionMultipleChoice(const KDateTime &selectedOccurrence,
-        const QString &message, const QString &caption,
-        const KGuiItem &action, int availableChoices,
-        int preselectedChoices, QWidget *parent)
+int RecurrenceActions::questionMultipleChoice(const QDateTime &selectedOccurrence, const QString &message, const QString &caption, const KGuiItem &action, int availableChoices, int preselectedChoices,
+                                              QWidget *parent)
 {
     QDialogButtonBox::StandardButtons buttons = QDialogButtonBox::Ok | QDialogButtonBox::Cancel;
     ScopeWidget *widget = new ScopeWidget(availableChoices, selectedOccurrence, 0);
-    QDialogButtonBox *buttonBox = 0;
+    QDialogButtonBox *buttonBox = nullptr;
     auto dialog = createDialog(buttons, caption, widget, &buttonBox, parent);
 
     KGuiItem::assign(buttonBox->button(QDialogButtonBox::Ok), action);
@@ -203,9 +198,7 @@ int RecurrenceActions::questionMultipleChoice(const KDateTime &selectedOccurrenc
     return widget->checkedChoices();
 }
 
-int RecurrenceActions::questionSelectedAllCancel(const QString &message, const QString &caption,
-        const KGuiItem &actionSelected,
-        const KGuiItem &actionAll, QWidget *parent)
+int RecurrenceActions::questionSelectedAllCancel(const QString &message, const QString &caption, const KGuiItem &actionSelected, const KGuiItem &actionAll, QWidget *parent)
 {
     QPointer<QDialog> dialog = new QDialog(parent);
     dialog->setWindowTitle(caption);
@@ -224,14 +217,14 @@ int RecurrenceActions::questionSelectedAllCancel(const QString &message, const Q
 
     bool checkboxResult = false;
     int result = KMessageBox::createKMessageBox(
-                     dialog,
-                     buttonBox,
-                     QMessageBox::Question,
-                     message,
-                     QStringList(),
-                     QString(),
-                     &checkboxResult,
-                     KMessageBox::Notify);
+        dialog,
+        buttonBox,
+        QMessageBox::Question,
+        message,
+        QStringList(),
+        QString(),
+        &checkboxResult,
+        KMessageBox::Notify);
 
     switch (result) {
     case QDialogButtonBox::Yes:
@@ -245,12 +238,8 @@ int RecurrenceActions::questionSelectedAllCancel(const QString &message, const Q
     return NoOccurrence;
 }
 
-int RecurrenceActions::questionSelectedFutureAllCancel(const QString &message,
-        const QString &caption,
-        const KGuiItem &actionSelected,
-        const KGuiItem &actionFuture,
-        const KGuiItem &actionAll,
-        QWidget *parent)
+int RecurrenceActions::questionSelectedFutureAllCancel(const QString &message, const QString &caption, const KGuiItem &actionSelected, const KGuiItem &actionFuture, const KGuiItem &actionAll,
+                                                       QWidget *parent)
 {
     QPointer<QDialog> dialog = new QDialog(parent);
     dialog->setWindowTitle(caption);
@@ -269,14 +258,14 @@ int RecurrenceActions::questionSelectedFutureAllCancel(const QString &message,
 
     bool checkboxResult = false;
     int result = KMessageBox::createKMessageBox(
-                     dialog,
-                     buttonBox,
-                     QMessageBox::Question,
-                     message,
-                     QStringList(),
-                     QString(),
-                     &checkboxResult,
-                     KMessageBox::Notify);
+        dialog,
+        buttonBox,
+        QMessageBox::Question,
+        message,
+        QStringList(),
+        QString(),
+        &checkboxResult,
+        KMessageBox::Notify);
 
     switch (result) {
     case QDialogButtonBox::Yes:
