@@ -47,7 +47,7 @@ Scheduler::Scheduler(const Calendar::Ptr &calendar) : d(new KCalUtils::Scheduler
 {
     mCalendar = calendar;
     mFormat = new ICalFormat();
-    mFormat->setTimeSpec(calendar->timeSpec());
+    mFormat->setTimeZone(calendar->timeZone());
 }
 
 Scheduler::~Scheduler()
@@ -338,7 +338,7 @@ bool Scheduler::acceptCancel(const IncidenceBase::Ptr &incidence, ScheduleMessag
     }
 
     // in case we didn't find the to-be-removed incidence
-    if (existingIncidences.count() > 0 && inc->revision() > 0) {
+    if (!existingIncidences.isEmpty() && inc->revision() > 0) {
         KMessageBox::error(
             nullptr,
             i18nc("@info",
